@@ -6,6 +6,8 @@
 void *mma_calloc(MM *, size_t, size_t);
 void *mma_malloc(MM *, size_t);
 void  mma_free  (MM *, void *);
-int mma_sizeok (void *ptr, const size_t usize);
+int   mma_sizeok (void *ptr, const size_t usize);
+inline int mma_alloc_mask(void);
+inline int mma_alloc_base(void);
 
 #endif /* _MMA_ALLOC_H_ */
